﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Web.UI.WebControls;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using Microsoft.SharePoint.Administration;
using Microsoft.SharePoint.ApplicationPages;
using SecurityEventManagement;


namespace ManageSecurityAuditSettings
{
    public class ManageSecurityAuditSettings : GlobalAdminPageBase
    {
        protected CustomValidator pageValidator;
        protected TextBox txtSiteURL;
        protected TextBox txtListName;
        protected DropDownList ddwnEventFilter;
        protected EncodedLiteral ErrorMessage;

        protected override void OnLoad(EventArgs args)
        {
            base.OnLoad(args);

            if (this.IsPostBack) return;

            SecurityEventReceiverService EventReceiverService =
                SPFarm.Local.Services.GetValue<SecurityEventReceiverService>(
                SecurityEventReceiverService.ntServiceName);

            if (EventReceiverService == null)
                throw new Exception("Unable to locate SecurityEventReceiverService "
                                    + "in the local SharePoint farm.");

            txtSiteURL.Text = EventReceiverService.SiteURL;
            txtListName.Text = EventReceiverService.ListName;

            foreach (ListItem item in ddwnEventFilter.Items)
            {
                if (string.Compare(item.Value, EventReceiverService.EventFilter, true) == 0)
                {
                    item.Selected = true;
                    break;
                }
            }
        }

        public override string PageToRedirectOnCancel
        {
            get
            {
                return "../Server.aspx";
            }
        }

        protected void BtnSubmit_Click(object sender, EventArgs args)
        {
            if (this.Page.IsValid)
            {
                SecurityEventReceiverService EventReceiverService =
                    SPFarm.Local.Services.GetValue<SecurityEventReceiverService>(
                    SecurityEventReceiverService.ntServiceName);

                if (EventReceiverService == null)
                    throw new Exception("Unable to locate SecurityEventReceiverService " + 
                                        "in the local SharePoint farm.");

                EventReceiverService.SiteURL = txtSiteURL.Text;
                EventReceiverService.ListName = txtListName.Text;
                EventReceiverService.EventFilter = ddwnEventFilter.SelectedValue;
                EventReceiverService.Update();

                Response.Redirect("../Server.aspx");
            }
        }

        protected void ValidateOnSubmit(object sender, ServerValidateEventArgs args)
        {
            //
            //  The event filter can only have three possible values.
            //
            if (string.Compare(ddwnEventFilter.SelectedValue, "FailureAudit", true) != 0 &&
                string.Compare(ddwnEventFilter.SelectedValue, "SuccessAudit", true) != 0 &&
                string.Compare(ddwnEventFilter.SelectedValue, "FailureAudit|SuccessAudit", true) != 0)
            {
                ErrorMessage.Visible = true;
                ErrorMessage.Text = Environment.NewLine + "Invalid Audit Mode";
                args.IsValid = false;
            }
            else
            {
                //
                //  The specified target site and Security Audit list must be accessible.
                //
                try
                {
                    //
                    //  Access the site and create the item in the specified list.
                    //
                    using (SPSite site = new SPSite(txtSiteURL.Text))
                    using (SPWeb web = site.OpenWeb())
                    {
                        if (web.Lists[txtListName.Text] == null)
                            throw new Exception("Unable to access the target Security Audit list. " +
                                "Either the specified target site or list does not exist or " +
                                "your account does not have access permissions.");
                    }
                    args.IsValid = true;
                }
                catch (Exception ee)
                {
                    ErrorMessage.Visible = true;
                    ErrorMessage.Text = Environment.NewLine + ee.Message;
                    args.IsValid = false;
                }
            }
        }
    }
}
